@@ -3,6 +3,7 @@ import os
 from flask import Blueprint, send_from_directory
 from flask_restful import Api, Resource
 
+from aim.web.app.projects.project import Project
 
 general_bp = Blueprint('general', __name__)
 general_api = Api(general_bp)
@@ -33,7 +34,8 @@ class ServeStaticFiles(Resource):
 @general_api.resource('/static/<exp_name>/<commit_hash>/media/images/<path>')
 class ServeImages(Resource):
     def get(self, exp_name, commit_hash, path):
-        images_dir = os.path.join(os.getcwd(), '.aim',
+        project = Project()
+        images_dir = os.path.join(project.repo_path,
                                   exp_name, commit_hash,
                                   'objects', 'media', 'images')
         return send_from_directory(images_dir, path)
